==> order-center-infrastructure-3.0.0-CLOUD-DEV-20250411.091305-147-sources.jar: com/tydic/dyc/oc/repository/po/UocShipOrderPo.java <==
package com.tydic.dyc.oc.repository.po;

import com.tydic.utils.generatedoc.annotation.DocField;
import lombok.Data;

import java.io.Serializable;
import java.util.Date;
import java.util.List;

/**
 * 标题:UocShipOrderPo
 * 说明:发货单
 * 时间:2022-05-20 10:11
 * 作者:罗有
 **/
@Data
public class UocShipOrderPo implements Serializable {
	private static final long serialVersionUID = -5730044681154456369L;

	@DocField(value = "发货单id")
	private Long shipOrderId;

	@DocField(value = "销售单id")
	private Long saleOrderId;

	@DocField(value = "订单id")
	private Long orderId;

	@DocField(value = "发货单编码")
	private String shipOrderNo;

	@DocField(value = "外部发货单编码")
	private String shipOrderNoExt;

	@DocField(value = "发货单名称")
	private String shipOrderName;

	@DocField(value = "发货单类型")
	private Integer shipOrderType;

	@DocField(value = "订单状态")
	private String shipOrderState;

	@DocField(value = "供应商编码")
	private String supNo;

	@DocField(value = "供应商账户")
	private String supAccount;

	@DocField(value = "物流公司id")
	private String shipCompanyId;

	@DocField(value = "物流公司名称")
	private String shipCompanyName;

	@DocField(value = "发货时间")
	private Date shipTime;

	@DocField(value = "发货时间 开始")
	private Date shipTimeStart;

	@DocField(value = "发货时间 结束")
	private Date shipTimeEnd;

	@DocField(value = "发货联系人姓名")
	private String shipName;

	@DocField(value = "发货联系人电话")
	private String shipPhone;

	@DocField(value = "发货工号")
	private String shipOperId;

	@DocField(value = "预计到货时间")
	private Date estimateArrivalTime;

	@DocField(value = "预计到货时间 开始")
	private Date estimateArrivalTimeStart;

	@DocField(value = "预计到货时间 结束")
	private Date estimateArrivalTimeEnd;

	@DocField(value = "到货时间")
	private Date arriveTime;

	@DocField(value = "到货时间 开始")
	private Date arriveTimeStart;

	@DocField(value = "到货时间 结束")
	private Date arriveTimeEnd;

	@DocField(value = "验收时间-该发货单全部被验收")
	private Date inspTime;

	@DocField(value = "验收时间-该发货单全部被验收 开始")
	private Date inspTimeStart;

	@DocField(value = "验收时间-该发货单全部被验收 结束")
	private Date inspTimeEnd;

	@DocField(value = "是否包含附件")
	private Integer isEnclosure;

	@DocField(value = "发货备注")
	private String shipRemark;

	@DocField(value = "到货备注")
	private String arriveRemark;

	@DocField(value = "验收人电话")
	private String inspOperPhone;

	@DocField(value = "验收人名字")
	private String inspOperId;

	@DocField(value = "验收人名称")
	private String inspOperName;

	@DocField(value = "收/拒收 货人")
	private String receiverUser;

	@DocField(value = "收/拒收 货备注")
	private String receiverRemark;

	@DocField(value = "收/拒收 联系人")
	private String receiverContact;

	@DocField(value = "收/拒收 时间")
	private Date receiverTime;

	@DocField(value = "收/拒收 时间 开始")
	private Date receiverTimeStart;

	@DocField(value = "收/拒收 时间 结束")
	private Date receiverTimeEnd;

	@DocField(value = "是否可以异常变更：1：不允许；其他情况都可以")
	private Integer isAbnormal;

	@DocField(value = "流转状态")
	private String procState;

	@DocField(value = "竣工标志             1 竣工             0 在途")
	private Integer finishFlag;

	@DocField(value = "租户ID")
	private String tenantId;

	@DocField(value = "创建时间")
	private Date createTime;

	@DocField(value = "创建时间 开始")
	private Date createTimeStart;

	@DocField(value = "创建时间 结束")
	private Date createTimeEnd;

	@DocField(value = "创建工号")
	private String createOperId;

	@DocField(value = "更新时间")
	private Date updateTime;

	@DocField(value = "更新时间 开始")
	private Date updateTimeStart;

	@DocField(value = "更新时间 结束")
	private Date updateTimeEnd;

	@DocField(value = "更新工号")
	private String updateOperId;

	@DocField(value = "撤单时间")
	private Date cancelTime;

	@DocField(value = "撤单时间 开始")
	private Date cancelTimeStart;

	@DocField(value = "撤单时间 结束")
	private Date cancelTimeEnd;

	@DocField(value = "撤单工号")
	private String cancelOperId;

	@DocField(value = "撤单原因")
	private String cancelReason;

	@DocField(value = "撤单标志:1 已撤单             0 未撤单")
	private Integer cancelFlag;

	@DocField(value = "物流单号")
	private String shipCompanyNo;

	@DocField(value = "车牌号")
	private String carNo;

	@DocField(value = "运输方式，1汽运，2三方物流")
	private Integer transportMode;

	@DocField(value = "允许变更时限")
	private Date allowChngTime;

	@DocField(value = "允许变更时限 开始")
	private Date allowChngTimeStart;

	@DocField(value = "允许变更时限 结束")
	private Date allowChngTimeEnd;

	@DocField(value = "备注")
	private String remark;

	@DocField(value = "竣工时间")
	private Date finishTime;

	@DocField(value = "竣工时间 开始")
	private Date finishTimeStart;

	@DocField(value = "竣工时间 结束")
	private Date finishTimeEnd;

	@DocField(value = "逾期时间")
	private Date expTime;

	@DocField(value = "逾期时间 开始")
	private Date expTimeStart;

	@DocField(value = "逾期时间 结束")
	private Date expTimeEnd;

	@DocField(value = "扩展字段1")
	private String extField1;

	@DocField(value = "扩展字段2")
	private String extField2;

	@DocField(value = "扩展字段3")
	private String extField3;

	@DocField(value = "扩展字段4")
	private String extField4;

	@DocField(value = "扩展字段5")
	private String extField5;

	@DocField(value = "删除标志1已删除")
	private Integer delTag;

		@DocField(value = "排序")
	private String orderBy;

	@DocField(value = "租户id")
	private Long sysTenantId;

	@DocField(value = "租户名称")
	private String sysTenantName;

	@DocField(value = "发货单IDList")
	private List<Long> shipOrderIdList;

}

==> order-center-infrastructure-3.2.3-CLOUD-DEV-20241125.101543-26-sources.jar: com/tydic/dyc/oc/repository/po/UocShipOrderPo.java <==
package com.tydic.dyc.oc.repository.po;


import lombok.Data;
import lombok.EqualsAndHashCode;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 标题:UocShipOrderPo
 * 说明:发货单
 * 时间:2022-05-20 10:11
 * 作者:罗有
 **/
@Data
@EqualsAndHashCode(callSuper=false)
public class UocShipOrderPo implements Serializable {
	private static final long serialVersionUID = -5730044681154456369L;

	//发货单id")
	private Long shipOrderId;

	//销售单id")
	private Long saleOrderId;

	//订单id")
	private Long orderId;

	//发货单编码")
	private String shipOrderNo;

	//外部发货单编码")
	private String shipOrderNoExt;

	//发货单名称")
	private String shipOrderName;

	//发货单类型")
	private Integer shipOrderType;

	//订单状态")
	private String shipOrderState;

	//供应商编码")
	private String supNo;

	//供应商账户")
	private String supAccount;

	//物流公司id")
	private String shipCompanyId;

	//物流公司名称")
	private String shipCompanyName;

	//发货时间")
	private Date shipTime;

	//发货时间 开始")
	private Date shipTimeStart;

	//发货时间 结束")
	private Date shipTimeEnd;

	//发货联系人姓名")
	private String shipName;

	//发货联系人电话")
	private String shipPhone;

	//发货工号")
	private String shipOperId;

	//预计到货时间")
	private Date estimateArrivalTime;

	//预计到货时间 开始")
	private Date estimateArrivalTimeStart;

	//预计到货时间 结束")
	private Date estimateArrivalTimeEnd;

	//到货时间")
	private Date arriveTime;

	//到货时间 开始")
	private Date arriveTimeStart;

	//到货时间 结束")
	private Date arriveTimeEnd;

	//验收时间-该发货单全部被验收")
	private Date inspTime;

	//验收时间-该发货单全部被验收 开始")
	private Date inspTimeStart;

	//验收时间-该发货单全部被验收 结束")
	private Date inspTimeEnd;

	//是否包含附件")
	private Integer isEnclosure;

	//发货备注")
	private String shipRemark;

	//到货备注")
	private String arriveRemark;

	//验收人电话")
	private String inspOperPhone;

	//验收人名字")
	private String inspOperId;

	//验收人名称")
	private String inspOperName;

	//收/拒收 货人")
	private String receiverUser;

	//收/拒收 货备注")
	private String receiverRemark;

	//收/拒收 联系人")
	private String receiverContact;

	//收/拒收 时间")
	private Date receiverTime;

	//收/拒收 时间 开始")
	private Date receiverTimeStart;

	//收/拒收 时间 结束")
	private Date receiverTimeEnd;

	//是否可以异常变更：1：不允许；其他情况都可以")
	private Integer isAbnormal;

	//流转状态")
	private String procState;

	//竣工标志             1 竣工             0 在途")
	private Integer finishFlag;

	//租户ID")
	private String tenantId;

	//创建时间")
	private Date createTime;

	//创建时间 开始")
	private Date createTimeStart;

	//创建时间 结束")
	private Date createTimeEnd;

	//创建工号")
	private String createOperId;

	//更新时间")
	private Date updateTime;

	//更新时间 开始")
	private Date updateTimeStart;

	//更新时间 结束")
	private Date updateTimeEnd;

	//更新工号")
	private String updateOperId;

	//撤单时间")
	private Date cancelTime;

	//撤单时间 开始")
	private Date cancelTimeStart;

	//撤单时间 结束")
	private Date cancelTimeEnd;

	//撤单工号")
	private String cancelOperId;

	//撤单原因")
	private String cancelReason;

	//撤单标志:1 已撤单             0 未撤单")
	private Integer cancelFlag;

	//物流单号")
	private String shipCompanyNo;

	//车牌号")
	private String carNo;

	//运输方式，1汽运，2三方物流")
	private Integer transportMode;

	//允许变更时限")
	private Date allowChngTime;

	//允许变更时限 开始")
	private Date allowChngTimeStart;

	//允许变更时限 结束")
	private Date allowChngTimeEnd;

	//备注")
	private String remark;

	//竣工时间")
	private Date finishTime;

	//竣工时间 开始")
	private Date finishTimeStart;

	//竣工时间 结束")
	private Date finishTimeEnd;

	//逾期时间")
	private Date expTime;

	//逾期时间 开始")
	private Date expTimeStart;

	//逾期时间 结束")
	private Date expTimeEnd;

	//扩展字段1")
	private String extField1;

	//扩展字段2")
	private String extField2;

	//扩展字段3")
	private String extField3;

	//扩展字段4")
	private String extField4;

	//扩展字段5")
	private String extField5;

	//删除标志1已删除")
	private Integer delTag;

	//排序")
	private String orderBy;

	//发货单IDList")
	private List<Long> shipOrderIdList;
	 //@DocField(value = "归档表后缀")
	private String dataAchiveTabSuffix;

	/**
	 * 发货单运费
	 */
	private BigDecimal sendTransFee;

	/**
	 * 发货单已占用运费
	 */
	private BigDecimal sendOccupyTransFee;

	/**
	 * 司机姓名
	 */
	private String driverName;

	/**
	 * 司机电话
	 */
	private String driverPhone;

}
